/**
 * 数组列表除了默认的新增按钮外，自定义的按钮组（每个按钮点击时会执行对应的callback，使用前请先咨询@侑夕）
 */
export interface UiSchemaExtraButton {
    text: string;
    icon: string;
    callback: string;
}


/**
 * 存放特定元素的特定配置。例如textarea的rows
 * @example "textareaDemo": {
 *   "ui:widget": "textarea",
 *   "ui:options": {
 *     "rows": 5
 *   }
 * }
 * 基本上所有antd文档中组件的 props 都可以使用 ui:options 的方式来直接使用。
 */
export interface UiSchemaOptions {
    /**
     * 用于长列表的收起和展开
     * 可用组件：列表（array）
     * @example `{ foldable: true }` 收起长列表
     */
    foldable: boolean;

    /**
     * 是否隐藏“删除”按钮
     * 可用组件：列表（array）
     * @example `{ hideDelete: true }` 隐藏“删除”按钮
     */
    hideDelete: boolean;
}
export interface UiSchema {
    'ui:widget': string;
    /**
     * 可控制 input、number、date、checkbox、radio、select、switch 对于组件的 disabled 属性(变灰不可点击)
     */
    'ui:disabled': boolean;
    /**
     * 可控制 input、number 组件中的 readonly 属性(不可编辑，但不变灰)，列表也支持readonly，效果是列
     * 表的控件都会隐藏，导致列表不能增、删和拖拽，进入“只读”模式。但注意列表内的内容还是允许修改的，
     * 所以特别要注意如果列表套列表的场景，内部的列表也要 "ui:readonly": true
     * @example "someList": {
     *   "ui:readonly": true
     * }
     */
    'ui:readonly': boolean;
    /**
     * 可控制所有基础组件是否显示，可使用 true/false 或表达式
     * @example "ui:hidden": false
     * @example "ui:hidden": "agree==false && personType!=2"
     */
    'ui:hidden': boolean | string;
    /**
     * 添加组件 root 元素的 className（和 fr-field 这个 className 在同级），用于自定义单独组件的样式
     */
    'ui:className': string;
    /**
     * 单个基础组件的长度，建议使用百分比例如"
     * @example "ui:width":"50%"
     */
    'ui:width': string;
    'ui:options': UiSchemaOptions;
    'ui:extraButtons': UiSchemaExtraButton[];
}
